umbra.components.addons.projectsExplorer.views — Umbra 1.0.9 documentation

# Source code for umbra.components.addons.projectsExplorer.views

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    """
    **views.py**

    **Platform:**
    	Windows, Linux, Mac Os X.

    **Description:**
    	Defines the :class:`umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer`
    	Component Interface class View.

    **Others:**

    """

    #**********************************************************************************************************************
    #***	Future imports.
    #**********************************************************************************************************************
    from __future__ import unicode_literals

    #**********************************************************************************************************************
    #***	External imports.
    #**********************************************************************************************************************
    from PyQt4.QtCore import Qt
    from PyQt4.QtGui import QAbstractItemView

    #**********************************************************************************************************************
    #***	Internal imports.
    #**********************************************************************************************************************
    import foundations.exceptions
    import foundations.verbose
    import umbra.ui.views

    #**********************************************************************************************************************
    #***	Module attributes.
    #**********************************************************************************************************************
    __author__ = "Thomas Mansencal"
    __copyright__ = "Copyright (C) 2008 - 2014 - Thomas Mansencal"
    __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
    __maintainer__ = "Thomas Mansencal"
    __email__ = "thomas.mansencal@gmail.com"
    __status__ = "Production"

    __all__ = ["LOGGER", "Projects_QTreeView"]

    LOGGER = foundations.verbose.installLogger()

    #**********************************************************************************************************************
    #***	Module classes and definitions.
    #**********************************************************************************************************************
    class Projects_QTreeView(umbra.ui.views.Abstract_QTreeView):
    	"""
    	Defines the view for Projects.
    	"""

    	def __init__(self, parent, model=None, readOnly=False, message=None):
    		"""
    		Initializes the class.

    		:param parent: Object parent.
    		:type parent: QObject
    		:param model: Model.
    		:type model: QObject
    		:param readOnly: View is read only.
    		:type readOnly: bool
    		:param message: View default message when Model is empty.
    		:type message: unicode
    		"""

    		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))

    		umbra.ui.views.Abstract_QTreeView.__init__(self, parent, readOnly, message)

    		# --- Setting class attributes. ---
    		self.__treeViewIndentation = 15

    		self.setModel(model)

    		Projects_QTreeView.__initializeUi(self)

    	#******************************************************************************************************************
    	#***	Attributes properties.
    	#******************************************************************************************************************
    	@property
    	def treeViewIndentation(self):
    		"""
    		Property for **self.__treeViewIndentation** attribute.

    		:return: self.__treeViewIndentation.
    		:rtype: int
    		"""

    		return self.__treeViewIndentation

    	@treeViewIndentation.setter
    # Oncilla: Statement commented by auto-documentation process: 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
    	def treeViewIndentation(self, value):
    		"""
    		Setter for **self.__treeViewIndentation** attribute.

    		:param value: Attribute value.
    		:type value: int
    		"""

    		raise foundations.exceptions.ProgrammingError(
    		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "treeViewIndentation"))

    	@treeViewIndentation.deleter
    # Oncilla: Statement commented by auto-documentation process: 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
    	def treeViewIndentation(self):
    		"""
    		Deleter for **self.__treeViewIndentation** attribute.
    		"""

    		raise foundations.exceptions.ProgrammingError(
    		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "treeViewIndentation"))

    	#******************************************************************************************************************
    	#***	Class methods.
    	#******************************************************************************************************************
    	def __initializeUi(self):
    		"""
    		Initializes the Widget ui.
    		"""

    		self.setAutoScroll(True)
    		self.setIndentation(self.__treeViewIndentation)
    		self.setRootIsDecorated(False)
    		self.setDragDropMode(QAbstractItemView.DragOnly)

    		self.header().hide()

    		self.setSortingEnabled(True)
    		self.sortByColumn(0, Qt.AscendingOrder)

    		self.__setDefaultUiState()

    		# Signals / Slots.
    		self.model().modelReset.connect(self.__setDefaultUiState)

    	def __setDefaultUiState(self):
    		"""
    		Sets the Widget default ui state.
    		"""

    		LOGGER.debug("> Setting default View state!")

    		if not self.model():
    			return

    		self.expandAll()

    	def setModel(self, model):
    		"""
    		Reimplements the **umbra.ui.views.Abstract_QTreeView.setModel** method.

    		:param model: Model to set.
    		:type model: QObject
    		"""

    		LOGGER.debug("> Setting '{0}' model.".format(model))

    		if not model:
    			return

    		umbra.ui.views.Abstract_QTreeView.setModel(self, model)